import { CSSObject } from 'styled-components';
import { ReactNode } from 'react';
import { IconName } from '@fortawesome/fontawesome-svg-core';
declare type ExtraPartial<T> = {
    [P in keyof T]?: T[P] extends Record<infer K, infer U> ? Partial<T[P]> : T[P];
};
export interface PlainObject {
    [index: string]: any;
}
export declare type HiroColors = 'primary' | 'secondary' | 'primaryText' | 'secondaryText' | 'red' | 'orange' | 'yellow' | 'green' | 'teal' | 'blue' | 'purple' | 'pink' | 'brown' | 'black' | 'grey' | 'white';
export declare type Greyscales = 'lightest' | 'lighter' | 'light' | 'medium' | 'dark' | 'darker' | 'darkest';
export declare type FixedWidth = string | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16;
export interface BreakpointDefinitions {
    sm: number;
    md: number;
    lg: number;
    xl: number;
}
export declare type ColorDefinitionValuesEnum = 'default' | 'active' | 'hover' | 'light' | 'dark' | 'verylight' | 'highlighted' | 'highlightedHover' | 'saturated' | 'disabled' | 'transparent' | 'verytransparent' | 'blured';
export declare type ColorDefinitionValues = Record<ColorDefinitionValuesEnum, string>;
export declare type SizeScale = 'mini' | 'tiny' | 'small' | 'medium' | 'large' | 'big' | 'huge' | 'massive';
export declare type ColorDefinitions = Record<HiroColors, ColorDefinitionValues>;
export declare type ColorOverwrite = {
    [C in ColorDefinitionValuesEnum]?: string;
} & {
    default: string;
};
export interface FontDefinitons {
    h1: CSSObject;
    h2: CSSObject;
    h3: CSSObject;
}
export declare type GreyscaleDefinitions = {
    [K in Greyscales]: string;
};
export interface SizeDefinitions {
    borderRadius: string | number;
    borderRadiusInput: string | number;
    padding: Record<'normal' | 'extra', string>;
    scale: Record<SizeScale, number>;
    width: BreakpointDefinitions;
}
export interface HiroDefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: Record<HiroColors, string | ColorOverwrite>;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
    name: string;
}
export interface HiroPartialTheme {
    name?: string;
    breakpoints?: ExtraPartial<BreakpointDefinitions>;
    colors?: ExtraPartial<Record<HiroColors, string | ColorOverwrite>>;
    font?: ExtraPartial<FontDefinitons>;
    global?: CSSObject;
    greyscale?: ExtraPartial<GreyscaleDefinitions>;
    sizes?: ExtraPartial<SizeDefinitions>;
}
export interface DefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: ColorDefinitions;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
}
declare module 'styled-components' {
    interface DefaultTheme {
        breakpoints: BreakpointDefinitions;
        colors: ColorDefinitions;
        font: FontDefinitons;
        global: CSSObject;
        greyscale: GreyscaleDefinitions;
        sizes: SizeDefinitions;
    }
}
export declare type HiroIcons = IconName;
export declare type renderType = () => ReactNode;
export interface VariablesProps {
    [key: string]: string[];
}
export interface Rules {
    start: Rule[];
}
export interface Rule {
    regex: string | null;
    token: string;
}
export {};
